@@ -293,6 +293,27 @@ class OWWOOpticalElement(WofryWidget, WidgetDecorator):
             pass
 
         self.setStatusMessage("")
+        try:
+            self.print_intensities()
+        except:
+            pass
+
+    def print_intensities(self):
+        input_wavefront = self.input_data.get_wavefront()
+        output_wavefront = self.wavefront_to_plot
+
+        c1 = input_wavefront.get_intensity().sum()
+        c2 = output_wavefront.get_intensity().sum()
+        dx1, dy1 = input_wavefront.delta()
+        dx2, dy2 = output_wavefront.delta()
+        i1 = input_wavefront.get_integrated_intensity()
+        i2 = output_wavefront.get_integrated_intensity()
+        print("\n\n\n ==========  integrated intensities: ")
+        print("input wavefront integrated intensity: %g" % (i1))
+        print("output wavefront integrated intensity: %g" % (i2))
+        print("output/input intensity ratio (transmission): %g " % (i2 / i1))
+        print("(input-output)/input intensity ratio (absorption): %g " % ((i1 - i2) / i1))
+        print("step in: (%g,%g) um, out: (%g,%g) um" % (1e6 * dx1, 1e6 * dy1, 1e6 * dx2, 1e6 * dy2))
 
     def get_handler_name(self):
         if self.propagator == 0:
